@@ -14,7 +14,7 @@
 class WP_Widget_Pages extends WP_Widget {
 
 	function __construct() {
-		$widget_ops = array('classname' => 'widget_pages', 'description' => __( 'Your site&#8217;s WordPress Pages') );
+		$widget_ops = array('classname' => 'widget_pages', 'description' => __( 'A list of your site&#8217;s Pages.') );
 		parent::__construct('pages', __('Pages'), $widget_ops);
 	}
 
@@ -190,7 +190,7 @@ class WP_Widget_Links extends WP_Widget {
 class WP_Widget_Search extends WP_Widget {
 
 	function __construct() {
-		$widget_ops = array('classname' => 'widget_search', 'description' => __( "A search form for your site") );
+		$widget_ops = array('classname' => 'widget_search', 'description' => __( "A search form for your site.") );
 		parent::__construct('search', __('Search'), $widget_ops);
 	}
 
@@ -233,7 +233,7 @@ class WP_Widget_Search extends WP_Widget {
 class WP_Widget_Archives extends WP_Widget {
 
 	function __construct() {
-		$widget_ops = array('classname' => 'widget_archive', 'description' => __( 'A monthly archive of your site&#8217;s posts') );
+		$widget_ops = array('classname' => 'widget_archive', 'description' => __( 'A monthly archive of your site&#8217;s Posts.') );
 		parent::__construct('archives', __('Archives'), $widget_ops);
 	}
 
@@ -298,7 +298,7 @@ class WP_Widget_Archives extends WP_Widget {
 class WP_Widget_Meta extends WP_Widget {
 
 	function __construct() {
-		$widget_ops = array('classname' => 'widget_meta', 'description' => __( "Log in/out, admin, feed and WordPress links") );
+		$widget_ops = array('classname' => 'widget_meta', 'description' => __( "Login, RSS, &amp; WordPress.org links.") );
 		parent::__construct('meta', __('Meta'), $widget_ops);
 	}
 
@@ -350,7 +350,7 @@ class WP_Widget_Meta extends WP_Widget {
 class WP_Widget_Calendar extends WP_Widget {
 
 	function __construct() {
-		$widget_ops = array('classname' => 'widget_calendar', 'description' => __( 'A calendar of your site&#8217;s posts') );
+		$widget_ops = array('classname' => 'widget_calendar', 'description' => __( 'A calendar of your site&#8217;s Posts.') );
 		parent::__construct('calendar', __('Calendar'), $widget_ops);
 	}
 
@@ -391,7 +391,7 @@ class WP_Widget_Calendar extends WP_Widget {
 class WP_Widget_Text extends WP_Widget {
 
 	function __construct() {
-		$widget_ops = array('classname' => 'widget_text', 'description' => __('Arbitrary text or HTML'));
+		$widget_ops = array('classname' => 'widget_text', 'description' => __('Arbitrary text or HTML.'));
 		$control_ops = array('width' => 400, 'height' => 350);
 		parent::__construct('text', __('Text'), $widget_ops, $control_ops);
 	}
@@ -441,7 +441,7 @@ class WP_Widget_Text extends WP_Widget {
 class WP_Widget_Categories extends WP_Widget {
 
 	function __construct() {
-		$widget_ops = array( 'classname' => 'widget_categories', 'description' => __( "A list or dropdown of categories" ) );
+		$widget_ops = array( 'classname' => 'widget_categories', 'description' => __( "A list or dropdown of categories." ) );
 		parent::__construct('categories', __('Categories'), $widget_ops);
 	}
 
@@ -533,7 +533,7 @@ class WP_Widget_Categories extends WP_Widget {
 class WP_Widget_Recent_Posts extends WP_Widget {
 
 	function __construct() {
-		$widget_ops = array('classname' => 'widget_recent_entries', 'description' => __( "The most recent posts on your site") );
+		$widget_ops = array('classname' => 'widget_recent_entries', 'description' => __( "Your site&#8217;s most recent Posts.") );
 		parent::__construct('recent-posts', __('Recent Posts'), $widget_ops);
 		$this->alt_option_name = 'widget_recent_entries';
 
@@ -635,7 +635,7 @@ class WP_Widget_Recent_Posts extends WP_Widget {
 class WP_Widget_Recent_Comments extends WP_Widget {
 
 	function __construct() {
-		$widget_ops = array('classname' => 'widget_recent_comments', 'description' => __( 'The most recent comments' ) );
+		$widget_ops = array('classname' => 'widget_recent_comments', 'description' => __( 'Your site&#8217;s most recent comments.' ) );
 		parent::__construct('recent-comments', __('Recent Comments'), $widget_ops);
 		$this->alt_option_name = 'widget_recent_comments';
 
@@ -742,7 +742,7 @@ class WP_Widget_Recent_Comments extends WP_Widget {
 class WP_Widget_RSS extends WP_Widget {
 
 	function __construct() {
-		$widget_ops = array( 'description' => __('Entries from any RSS or Atom feed') );
+		$widget_ops = array( 'description' => __('Entries from any RSS or Atom feed.') );
 		$control_ops = array( 'width' => 400, 'height' => 200 );
 		parent::__construct( 'rss', __('RSS'), $widget_ops, $control_ops );
 	}
@@ -1033,7 +1033,7 @@ function wp_widget_rss_process( $widget_rss, $check_feed = true ) {
 class WP_Widget_Tag_Cloud extends WP_Widget {
 
 	function __construct() {
-		$widget_ops = array( 'description' => __( "Your most used tags in cloud format") );
+		$widget_ops = array( 'description' => __( "A cloud of your most used tags.") );
 		parent::__construct('tag_cloud', __('Tag Cloud'), $widget_ops);
 	}
 
@@ -1100,7 +1100,7 @@ class WP_Widget_Tag_Cloud extends WP_Widget {
  class WP_Nav_Menu_Widget extends WP_Widget {
 
 	function __construct() {
-		$widget_ops = array( 'description' => __('Use this widget to add one of your custom menus as a widget.') );
+		$widget_ops = array( 'description' => __('Add a custom menu to your sidebar.') );
 		parent::__construct( 'nav_menu', __('Custom Menu'), $widget_ops );
 	}
 
